@@ -1,4 +1,4 @@
-from .model import Field, FieldCardinality, Message, Option
+from .ast import Field, FieldCardinality, Message, Option
 from .parser import Parser
 
 __all__ = ["Parser", "Message", "Field", "Option", "FieldCardinality"]
